"use strict";

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _objectWithoutProperties2 = require("babel-runtime/helpers/objectWithoutProperties");

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _extends2 = require("babel-runtime/helpers/extends");

var _extends3 = _interopRequireDefault(_extends2);

var _ramda = require("ramda");

var _ramda2 = _interopRequireDefault(_ramda);

var _fp = require("date-fns/fp");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var map = _ramda2.default.addIndex(_ramda2.default.map);

var sigFig = function sigFig(sf) {
	return function (x) {
		return parseFloat(x.toPrecision(sf), 10);
	};
};

var filterTasks = function filterTasks(config) {
	return _ramda2.default.filter(config.filterTask);
};

var addRenderingMetaToTasks = function addRenderingMetaToTasks(config) {
	var giveColor = config.giveColor;

	return map(function (task, i) {
		return (0, _extends3.default)({}, task, {
			i: i,
			score: sigFig(3)(task.score),
			color: giveColor(task)
		});
	});
};

var formatDateDistance = _ramda2.default.pipe(_fp.toDate, (0, _fp.formatDistanceStrictWithOptions)({
	addSuffix: true
})(new Date()));

var addPlusToTags = _ramda2.default.pipe(_ramda2.default.map(function (x) {
	return "+" + x;
}), _ramda2.default.join(" "));

var stringfiyTasksFields = function stringfiyTasksFields(tasks) {
	return _ramda2.default.map(_ramda2.default.pipe(_ramda2.default.evolve({
		created: formatDateDistance,
		done: formatDateDistance,
		due: formatDateDistance,
		start: formatDateDistance,
		stop: formatDateDistance,
		tags: addPlusToTags,
		updated: formatDateDistance,
		wait: formatDateDistance,
		depends: function depends(uuid) {
			return "" + _ramda2.default.findIndex(_ramda2.default.propEq("uuid", uuid), tasks);
		},
		recur: function recur(_ref) {
			var n = _ref.n,
			    period = _ref.period;
			return n + " " + {
				d: "days",
				w: "weeks",
				m: "months",
				y: "years"
			}[period];
		}
	}), function (_ref2) {
		var i = _ref2.i,
		    color = _ref2.color,
		    score = _ref2.score,
		    rest = (0, _objectWithoutProperties3.default)(_ref2, ["i", "color", "score"]);
		return (0, _extends3.default)({
			i: i,
			color: color,
			score: score
		}, _ramda2.default.map(function (x) {
			return "" + x;
		}, rest));
	}))(tasks);
};

exports.default = function (_ref3) {
	var config = _ref3.config,
	    height = _ref3.height;
	return _ramda2.default.pipe(filterTasks(config), _ramda2.default.slice(0, height - 4), addRenderingMetaToTasks(config), stringfiyTasksFields, _ramda2.default.sortBy(_ramda2.default.prop("score")), _ramda2.default.reverse);
};